package sgc.portal.cd.cd0101.persistence;
import java.util.List;

import org.apache.ibatis.annotations.Mapper;

import sgc.portal.base.util.EasyHashMap;
import sgc.portal.cd.cd0101.dto.CD01010001USearch;
import sgc.portal.cd.cd0101.model.CD01010001U;
import sgc.portal.cd.cd0101.model.CD01010002U;
import sgc.portal.cd.cd0101.model.CD01010003U;

@Mapper
public interface CD01010001UMapper {
	//공종
	//공종 조회
	List<EasyHashMap<String, Object>> selectConDayMstJobtypList(CD01010001USearch search);
	
	//공종 추가 삭제 수정
	int selectConDayMstJobtypCount(CD01010001U cD01010001U);
	void insertConDayMstJobtyp(CD01010001U cD01010001U);
	void updateConDayMstJobtyp(CD01010001U cD01010001U);
	void deleteConDayMstJobtyp(CD01010001U cD01010001U);
	
	//장비
	//장비 조회
	List<EasyHashMap<String, Object>> selectConDayMstEqpmList(CD01010001USearch search);
	
	//장비 추가 삭제 수정
	int selectConDayMstEqpmCount(CD01010002U cD01010002U);
	void insertConDayMstEqpm(CD01010002U cD01010002U);
	void updateConDayMstEqpm(CD01010002U cD01010002U);
	void deleteConDayMstEqpm(CD01010002U cD01010002U);
	
	
	//자재
	//자재 조회
	List<EasyHashMap<String, Object>> selectConDayMstBdmtList(CD01010001USearch search);
	
	//자재 추가 삭제 수정
	int selectConDayMstBdmtCount(CD01010003U cD01010003U);
	void insertConDayMstBdmt(CD01010003U cD01010003U);
	void updateConDayMstBdmt(CD01010003U cD01010003U);
	void deleteConDayMstBdmt(CD01010003U cD01010003U);
}